@@ -1,7 +1,9 @@
+import functools
 from typing import Iterator
 
 import numpy as np
 import pandas as pd
+import dask.dataframe as dd
 from pandera.errors import SchemaError
 
 from .file_loader_configuration import FileLoaderConfiguration
@@ -29,6 +31,8 @@ class DataFrameOutput:
     :type processed: pd.DataFrame
     """
 
+    MAX_ROWS_IN_FRAME = 100000
+
     def __init__(self, source: pd.DataFrame, processed: pd.DataFrame):
         self.source = source
         self.processed = processed
@@ -140,8 +144,10 @@ class DataFrameLoader:
         """
         if configuration.process == 'passthrough':
             return source_df.copy()
-        
-        renamed_df = source_df.rename(columns=configuration.renames)
+
+        split_df = self.__split_df(source_df)
+
+        renamed_df = split_df.rename(columns=configuration.renames)
 
         for field in configuration.dynamic_fields:
             self.reporter.report_debug(f"Processing dynamic field {field.name} - Data frame field {field.has_df_func()}")
@@ -149,7 +155,11 @@ class DataFrameLoader:
                 if field.has_df_func():
                     renamed_df = field.df_func(renamed_df)
                 else:
-                    renamed_df[field.name] = renamed_df.apply(field.func, axis=1)
+                    if isinstance(renamed_df, dd.DataFrame):
+                        type = configuration.get_field_type(field.name)
+                        renamed_df[field.name] = renamed_df.apply(field.func, axis=1, meta=(field.name, type))
+                    else:
+                        renamed_df[field.name] = renamed_df.apply(field.func, axis=1)
             except Exception as e:
                 if field.suppress_errors:
                     self.reporter.report_error(e)
@@ -166,10 +176,16 @@ class DataFrameLoader:
                 output[key] = output[key].replace([np.nan, np.inf, -np.inf], 0)
             output[key] = output[key].astype(value)
 
-        self.__validate_schema(output, configuration)
+        if isinstance(output, dd.DataFrame):
+            procesed = output.compute()
+        else:
+            procesed = output
 
-        return output
+        self.__validate_schema(procesed, configuration)
 
+        return procesed
+
+    @functools.lru_cache(maxsize=5)
     def load_file(self, configuration: FileLoaderConfiguration) -> Iterator[pd.DataFrame]:
         """
         Loads a data file based on its specified file type and associated configuration details
@@ -219,3 +235,23 @@ class DataFrameLoader:
                 self.reporter.report_debug(f'Schema validation failed but is disabled: {e}')
             else:
                 raise e
+
+    def __split_df(self, df: pd.DataFrame) -> pd.DataFrame | dd.DataFrame:
+        """
+        Splits the given DataFrame into smaller partitions if it exceeds the maximum
+        number of rows allowed for a single frame. This helps to handle large
+        datasets by creating a Dask DataFrame with multiple partitions.
+
+        :param df: Input DataFrame to be split, which can be a pandas DataFrame.
+        :type df: pd.DataFrame
+        :return: Returns the original DataFrame if the number of rows is within the
+            allowed limit. Otherwise, returns a Dask DataFrame partitioned into
+            8 segments.
+        :rtype: pd.DataFrame | dd.DataFrame
+        """
+        rows = len(df.index)
+
+        if rows <= DataFrameOutput.MAX_ROWS_IN_FRAME:
+            return df
+
+        return dd.from_pandas(df, npartitions=8)
